@@ -5,12 +5,13 @@ use 5.006002;
 use strict;
 use warnings;
 
-use base qw{ My::Module::Recommend::Any };
+use My::Module::Recommend::Any;
+our @ISA = qw{ My::Module::Recommend::Any };
 
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.076_03';
+our $VERSION = '0.077_01';
 
 our @EXPORT_OK = qw{ __all };
 
@@ -98,7 +99,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
