@@ -5,9 +5,9 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.076_03';
+our $VERSION = '0.077_01';
 
-use base qw{ Exporter };
+use Exporter qw{ import };
 
 use Astro::Coord::ECI::TLE qw{ :constants };
 use Astro::Coord::ECI::Utils qw{ rad2deg };
@@ -322,7 +322,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016 by Thomas R. Wyant, III
+Copyright (C) 2011-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
