@@ -11,7 +11,7 @@ use Astro::Coord::ECI::Utils qw{ __default_station PIOVER2 SECSPERDAY };
 use Exporter ();
 use POSIX qw{ floor };
 
-our $VERSION = '0.076_03';
+our $VERSION = '0.077_01';
 
 our @EXPORT_OK = qw{
     almanac almanac_hash
@@ -140,10 +140,10 @@ that wish to make use of the methods simply import them. Some of the
 methods require manifest constants to be defined; these are specified
 with the method.
 
-This package is B<private> to the C<Astro::Coord::ECI> package.
-Documentation is for the benefit of the author only. I am not opposed to
-making the interface public, but in the early going would like the
-liberty of being able to modify it without prior notice.
+This package is B<private> to the L<Astro::Coord::ECI|Astro::Coord::ECI>
+package.  Documentation is for the benefit of the author only. I am not
+opposed to making the interface public, but in the early going would
+like the liberty of being able to modify it without prior notice.
 
 =head1 METHODS
 
@@ -291,7 +291,7 @@ This package can not define any public attributes.
 
 =head1 SEE ALSO
 
-The C<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
+The L<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
 documentation for a discussion of how the pieces/parts of this
 distribution go together and how to use them.
 
@@ -306,7 +306,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012-2016 by Thomas R. Wyant, III
+Copyright (C) 2012-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
