@@ -26,9 +26,10 @@ Astro::Coord::ECI::Moon - Compute the position of the Moon.
 
 This module implements the position of the Moon as a function of time,
 as described in Jean Meeus' "Astronomical Algorithms," second edition.
-It is a subclass of B<Astro::Coord::ECI>, with the id, name, and diameter
-attributes initialized appropriately, and the time_set() method
-overridden to compute the position of the Moon at the given time.
+It is a subclass of L<Astro::Coord::ECI|Astro::Coord::ECI>, with the id,
+name, and diameter attributes initialized appropriately, and the
+time_set() method overridden to compute the position of the Moon at the
+given time.
 
 =head2 Methods
 
@@ -43,7 +44,7 @@ package Astro::Coord::ECI::Moon;
 use strict;
 use warnings;
 
-our $VERSION = '0.076_03';
+our $VERSION = '0.077_01';
 
 use base qw{Astro::Coord::ECI};
 
@@ -497,11 +498,11 @@ Algorithms" (second edition) formed the basis for this module.
 
 =head1 SEE ALSO
 
-The C<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
+The L<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
 documentation for a discussion of how the pieces/parts of this
 distribution go together and how to use them.
 
-The B<Astro-MoonPhase> package by Brett Hamilton, which contains a
+The L<Astro-MoonPhase> package by Brett Hamilton, which contains a
 function-based module to compute the current phase, distance and
 angular diameter of the Moon, as well as the angular diameter and
 distance of the Sun.
@@ -512,7 +513,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2016 by Thomas R. Wyant, III
+Copyright (C) 2005-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
