@@ -80,12 +80,13 @@ will need to substitute your own location where indicated.
 
 =head1 DESCRIPTION
 
-This class is a subclass of Astro::Coord::ECI::TLE, representing
+This class is a subclass of
+L<Astro::Coord::ECI::TLE|Astro::Coord::ECI::TLE>, representing
 original-design Iridium satellites. This class will probably B<not> work
-for the Iridium Next satellites, which are anticipated to be launched
-starting about 2015.
+for the Iridium Next satellites, which are being launched starting early
+2017.
 
-The Astro::Coord::ECI::TLE->parse method makes use of
+The C<< Astro::Coord::ECI::TLE->parse() >> method makes use of
 built-in data to determine which satellites to rebless into this class,
 based on the object's NORAD SATCAT ID. This internal data can be
 modified using the Astro::Coord::ECI::TLE->status method to correct
@@ -121,7 +122,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.076_03';
+our $VERSION = '0.077_01';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -1810,7 +1811,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2016 by Thomas R. Wyant, III
+Copyright (C) 2005-2017 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
